
# Quote script by Koloth, v1.0
# Jeremy Smith aka Koloth <smij0016@unf.edu>
# No need to configure, defaults are preset.
# This script requires alltools.tcl v1.3 <loaded by default on 1.4.x>
# This script requires mc.moretools, 1.1.9 was used.

##### Designed to operate with Eggdrop 1.5.2 && TCL 8.2+ ####


### DEFAULT COMMANDS AND INFO ######################################
# { all commands are typed in channel }
#
# addquote <quote>
# ### This adds quotes to the storage file, quotes can contain any type of character.
# ### Default access: everyone
#
# delquote <num/search> <quote number/exact quote>
# ### Searches for quote number, or exact match of specified quote and deletes it.
# ### Default access: global/channel operators
#
# selquote <num>
# ### Prints out the specified quote number.
# ### Default access: everyone
#
# quotes
# ### Prints out a random quote from the storage file.
# ### Default access: everyone
#
#
# Notes: Simple quote script, no super advanced features intended.
#        should work with 1.4.x as well.
#
####################################################################

set qot(vershort) "1.0"
set qot(verlong) "010000"

### SETTINGS ########################################################
set qot(cmd) ""
# Select this to your perferred command prefix, "" is acceptable.

set qot(file) "qot-stor.dat"
# This is where the quotes will be stored(standard ascii)

set qot(addflag) "-"
# Access required to add quotes, "-" is everyone.

set qot(delflag) "o|o"
# Access required to delete quotes.
#####################################################################


#### Eggdrop bindings ###############################################
bind pub $qot(addflag) [string trim $qot(cmd)]addquote qot_addquote
bind pub $qot(delflag)  [string trim $qot(cmd)]delquote qot_del
bind pub - [string trim $qot(cmd)]quotes qot_random
bind pub - [string trim $qot(cmd)]selquote qot_sel
#### Feel free to change commands if you understand this ############


#### TCL procs ####### Source is free to modify, however do not redistribute. ######

proc qot_addquote {nick uhost hand chan rest} {

    global qot
    set qot_fd [open $qot(file) a+]
    puts $qot_fd $rest
    close $qot_fd

    putchan $chan "Quote has been added to storage file."
    return
}

proc qot_random {nick uhost hand chan rest} {

    global qot
    if {![file exists $qot(file)]} {
	putchan $chan "Error: No quotes found--file does not exist"
	return
    } else {
	set qot_fd [open $qot(file) r]
    }
    for {set qot_cnt 0} { ![eof $qot_fd] } { incr qot_cnt } {
	gets $qot_fd qot_list($qot_cnt)
    }
    close $qot_fd
    set qot_cnt [expr $qot_cnt - 2]
    set qot_sel $qot_list([set qot_cur [rand [expr $qot_cnt + 1]]])
    putchan $chan "Quote [bold][expr $qot_cur + 1][bold] of [bold][expr $qot_cnt + 1][bold]: $qot_sel"
    return
}

proc qot_del {nick uhost hand chan rest} {


    global qot
    set type [lindex $rest 0]
    set rest [lrange $rest 1 end]
    if {![file exists $qot(file)]} {
	putchan $chan "Error: No quotes found--file does not exist"
	return
    } else {
	set qot_fd [open $qot(file) r]
    }
    for {set qot_cnt 0} { ![eof $qot_fd] } { incr qot_cnt 1 } {
	gets $qot_fd qot_list($qot_cnt)
    }
    close $qot_fd
    set qot_cnt [expr $qot_cnt - 2]
    if {$type == "num"} {
	set qot_fd [open $qot(file) w]
	for { set i 0 } { $i <= $qot_cnt } { incr i 1 } {
	    if {($qot_list($i) == "") || ($i == [expr $rest - 1])} {
		putchan $chan "Quote [bold][expr $i + 1][bold] deleted"
		continue
	    } else {
		puts $qot_fd $qot_list($i)
	    }
	}
	close $qot_fd
    } elseif {$type == "search"} {
	foreach qot_cur [array names qot_list] {
	    if {[string equal $rest $qot_list($qot_cur)]} {
		set qot_found 1
		set qot_todel $qot_cur
	    }
	}
	if {$qot_found} {
	    set qot_fd [open $qot(file) w]
	    for { set i 0 } { $i <= $qot_cnt } { incr i 1 } {
		if {($qot_list($i) == "") || ($i == $qot_todel)} {
		    putchan $chan "Quote [bold][expr $i + 1][bold] deleted"
		    continue
		} else {
		    puts $qot_fd $qot_list($i)
		}
	    }
	    close $qot_fd
	} else {
	    putchan $chan "Error: quote not found"
	    return
	}
    } else {
	putchan $chan "Error: invalid parameter"
	return
    }
}

proc qot_sel {nick uhost hand chan rest} {

    global qot
    if {![file exists $qot(file)]} {
	putchan $chan "Error: No quotes found--file does not exist"
	return
    }
    set qot_fd [open $qot(file) r]
    for {set qot_cnt 0} { ![eof $qot_fd] } { incr qot_cnt 1 } {
	gets $qot_fd qot_list($qot_cnt)
    }
    close $qot_fd
    set qot_cnt [expr $qot_cnt - 2]
    unset qot_list([expr $qot_cnt + 1])
    if {![info exists qot_list([expr $rest - 1])]} {
	putchan $chan "Error: that quote does not exist"
	return
    } else {
    set qot_sel $qot_list([expr $rest - 1])
    putchan $chan "Quote [bold]$rest[bold] of [bold][expr $qot_cnt + 1][bold]: $qot_sel"
    return
    }
    return
}


putlog "Quotes TCL script by Koloth, v$qot(vershort)"







